@@ -9,6 +9,8 @@ See http://toscawidgets.org/documentation/WidgetBrowser for more information
 import tw2.core as twc
 from widgets import *
 
+# note: this may be subject to change
+APIKEY = "ju6z9mjyajq2djue3gbvv26t"
 
 class DemoSelect2SingleSelectField(Select2SingleSelectField):
     options = [('Group 1', ['Item1', 'Item2']),
@@ -18,9 +20,28 @@ class DemoSelect2SingleSelectField(Select2SingleSelectField):
     ondemand=True
 
 class DemoSelect2AjaxSingleSelectField(Select2AjaxSingleSelectField):
+
+    resources = [twc.CSSSource(location="headbottom",
+        src=""" 
+            .zebra { background-color: #efefef; }
+             img.flag { height: 10px; width: 15px; padding-right: 10px; }
+            .movie-result td {vertical-align: top }
+            .movie-image { width: 60px; }
+            .movie-image img { height: 80px; width: 60px;  }
+            .movie-info { padding-left: 10px; vertical-align: top; }
+            .movie-title { font-size: 1.2em; padding-bottom: 15px; }
+            .movie-synopsis { font-size: .8em; color: #888; }
+            .select2-highlighted .movie-synopsis { font-size: .8em; color: #eee; }
+            .bigdrop.select2-container .select2-results {max-height: 300px;}
+            .bigdrop .select2-results {max-height: 300px;}
+            """
+            )]
+
+    attrs = dict(style='width: 100%;')
     options = []
     opts = dict(
-        placeholder=dict(title="Search for a movie", id=""),
+        #placeholder=dict(title="Search for a movie", id=""),
+        placeholder="Search for a movie...",
         minimumInputLength=2,
         ajax=dict(
             # instead of writing the function to execute the
@@ -33,10 +54,10 @@ class DemoSelect2AjaxSingleSelectField(Select2AjaxSingleSelectField):
                     return {
                         q: term, // search term
                         page_limit: 10,
-                        apikey: "t9vrcwd64b6hvfct3xvad7xz"
+                        apikey: "%s"
                     };
                 }
-                """),
+                """ % APIKEY ),
             results=twc.js_callback(
                 """
                 function (data, page) {
@@ -47,6 +68,23 @@ class DemoSelect2AjaxSingleSelectField(Select2AjaxSingleSelectField):
                 }
                 """),
         ),
+        initSelection=twc.js_callback("""
+            function(element, callback) {
+             // the input tag has a value attribute preloaded that points to a 
+             //preselected movie's id.  This function resolves that id attribute
+             // to an object that select2 can render using its formatResult 
+             // renderer - that way the movie name is shown preselected
+                var id=$(element).val();
+                if (id!=="") {
+                  $.ajax("http://api.rottentomatoes.com/api/public/v1.0/movies/"+id+".json", {
+                    data: {
+                      apikey: "%s"
+                    },
+                    dataType: "jsonp"
+                  }).done(function(data) { callback(data); });
+                }
+             }
+            """ % APIKEY),
         formatSelection=twc.js_callback(
             """
             function (movie) {
